@@ -20,12 +20,14 @@ import munch
 import netifaces
 import re
 import six
+import sre_constants
 import sys
 import time
 
 from decorator import decorator
 from heatclient import exc as heat_exc
 from neutronclient.common import exceptions as neutron_exc
+from novaclient import exceptions as nova_exc
 
 from shade import _log
 from shade import exc
@@ -76,6 +78,25 @@ def _iterate_timeout(timeout, message, wait=2):
     raise exc.OpenStackCloudTimeout(message)
 
 
+def _make_unicode(input):
+    """Turn an input into unicode unconditionally
+
+    :param input:
+       A unicode, string or other object
+    """
+    try:
+        if isinstance(input, unicode):
+            return input
+        if isinstance(input, str):
+            return input.decode('utf-8')
+        else:
+            # int, for example
+            return unicode(input)
+    except NameError:
+        # python3!
+        return str(input)
+
+
 def _filter_list(data, name_or_id, filters):
     """Filter a list by name/ID and arbitrary meta data.
 
@@ -99,15 +120,42 @@ def _filter_list(data, name_or_id, filters):
         OR
         A string containing a jmespath expression for further filtering.
     """
+    # The logger is shade.fmmatch to allow a user/operator to configure logging
+    # not to communicate about fnmatch misses (they shouldn't be too spammy,
+    # but one never knows)
+    log = _log.setup_logging('shade.fnmatch')
     if name_or_id:
+        # name_or_id might already be unicode
+        name_or_id = _make_unicode(name_or_id)
         identifier_matches = []
+        bad_pattern = False
+        try:
+            fn_reg = re.compile(fnmatch.translate(name_or_id))
+        except sre_constants.error:
+            # If the fnmatch re doesn't compile, then we don't care,
+            # but log it in case the user DID pass a pattern but did
+            # it poorly and wants to know what went wrong with their
+            # search
+            fn_reg = None
         for e in data:
-            e_id = e.get('id', None)
-            e_name = e.get('name', None)
-            if ((e_id and fnmatch.fnmatch(str(e_id), str(name_or_id))) or
-                    (e_name and fnmatch.fnmatch(
-                        str(e_name), str(name_or_id)))):
+            e_id = _make_unicode(e.get('id', None))
+            e_name = _make_unicode(e.get('name', None))
+
+            if ((e_id and e_id == name_or_id) or
+                    (e_name and e_name == name_or_id)):
                 identifier_matches.append(e)
+            else:
+                # Only try fnmatch if we don't match exactly
+                if not fn_reg:
+                    # If we don't have a pattern, skip this, but set the flag
+                    # so that we log the bad pattern
+                    bad_pattern = True
+                    continue
+                if ((e_id and fn_reg.match(e_id)) or
+                        (e_name and fn_reg.match(e_name))):
+                    identifier_matches.append(e)
+        if not identifier_matches and bad_pattern:
+            log.debug("Bad pattern passed to fnmatch", exc_info=True)
         data = identifier_matches
 
     if not filters:
@@ -434,6 +482,10 @@ def shade_exceptions(error_message=None):
         yield
     except exc.OpenStackCloudException:
         raise
+    except nova_exc.BadRequest as e:
+        if error_message is None:
+            error_message = str(e)
+        raise exc.OpenStackCloudBadRequest(error_message)
     except Exception as e:
         if error_message is None:
             error_message = str(e)
