@@ -18,6 +18,44 @@ Fakes used for testing
 """
 
 
+PROJECT_ID = '1c36b64c840a42cd9e9b931a369337f0'
+FLAVOR_ID = u'0c1d9008-f546-4608-9e8f-f8bdaec8dddd'
+CHOCOLATE_FLAVOR_ID = u'0c1d9008-f546-4608-9e8f-f8bdaec8ddde'
+STRAWBERRY_FLAVOR_ID = u'0c1d9008-f546-4608-9e8f-f8bdaec8dddf'
+COMPUTE_ENDPOINT = 'https://compute.example.com/v2.1/{project_id}'.format(
+    project_id=PROJECT_ID)
+
+
+def make_fake_flavor(flavor_id, name, ram=100, disk=1600, vcpus=24):
+    return {
+        u'OS-FLV-DISABLED:disabled': False,
+        u'OS-FLV-EXT-DATA:ephemeral': 0,
+        u'disk': disk,
+        u'id': flavor_id,
+        u'links': [{
+            u'href': u'{endpoint}/flavors/{id}'.format(
+                endpoint=COMPUTE_ENDPOINT, id=flavor_id),
+            u'rel': u'self'
+        }, {
+            u'href': u'{endpoint}/flavors/{id}'.format(
+                endpoint=COMPUTE_ENDPOINT, id=flavor_id),
+            u'rel': u'bookmark'
+        }],
+        u'name': name,
+        u'os-flavor-access:is_public': True,
+        u'ram': ram,
+        u'rxtx_factor': 1.0,
+        u'swap': u'',
+        u'vcpus': vcpus
+    }
+FAKE_FLAVOR = make_fake_flavor(FLAVOR_ID, 'vanilla')
+FAKE_CHOCOLATE_FLAVOR = make_fake_flavor(
+    CHOCOLATE_FLAVOR_ID, 'chocolate', ram=200)
+FAKE_STRAWBERRY_FLAVOR = make_fake_flavor(
+    STRAWBERRY_FLAVOR_ID, 'strawberry', ram=300)
+FAKE_FLAVOR_LIST = [FAKE_FLAVOR, FAKE_CHOCOLATE_FLAVOR, FAKE_STRAWBERRY_FLAVOR]
+
+
 class FakeEndpoint(object):
     def __init__(self, id, service_id, region, publicurl, internalurl=None,
                  adminurl=None):
